@@ -57,10 +57,6 @@ typos_path=`$current_dir/uut/typos.sh path $base_dir`
 typos_version=`$current_dir/uut/typos.sh version $base_dir`
 print_tool "typos" "$typos_version" "$typos_path" "$report_path"
 
-misspell_rs_path=`$current_dir/uut/misspell_rs.sh path $base_dir`
-misspell_rs_version=`$current_dir/uut/misspell_rs.sh version $base_dir`
-print_tool "misspell_rs" "$misspell_rs_version" "$misspell_rs_path" "$report_path"
-
 misspell_go_path=`$current_dir/uut/misspell_go.sh path $base_dir`
 misspell_go_version=`$current_dir/uut/misspell_go.sh version $base_dir`
 print_tool "misspell_go" "$misspell_go_version" "$misspell_go_path" "$report_path"
@@ -103,10 +99,6 @@ function bench_dir() {
       typos_ascii_command="$typos_path --no-unicode $path"
       typos_j1_command="$typos_path --threads 1 $path"
     fi
-    misspell_rs_command=""
-    if [[ ! -z $misspell_rs_path ]]; then
-      misspell_rs_command="$misspell_rs_path $path"
-    fi
     misspell_go_command=""
     if [[ ! -z $misspell_go_path ]]; then
       misspell_go_command="$misspell_go_path $path"
@@ -116,7 +108,7 @@ function bench_dir() {
     if [[ ! -z $codespell_path ]]; then
       codespell_command="$codespell_path $path"
     fi
-    hyperfine --warmup 1 -i --export-json $report_prefix-rg.json --export-markdown $report_prefix-rg.md "$rg_command" "$rg_j1_command" "$typos_command" "$typos_ascii_command" "$typos_j1_command" "$misspell_rs_command" "$misspell_go_command" "$codespell_command"
+    hyperfine --warmup 1 -i --export-json $report_prefix-rg.json --export-markdown $report_prefix-rg.md "$rg_command" "$rg_j1_command" "$typos_command" "$typos_ascii_command" "$typos_j1_command" "$misspell_go_command" "$codespell_command"
     cat $report_prefix-rg.md >> $output
   fi
   echo "" >> $output
@@ -146,10 +138,6 @@ function bench_file() {
       typos_command="$typos_path $path"
       typos_ascii_command="$typos_path --no-unicode $path"
     fi
-    misspell_rs_command=""
-    if [[ ! -z $misspell_rs_path ]]; then
-      misspell_rs_command="$misspell_rs_path $path"
-    fi
     misspell_go_command=""
     if [[ ! -z $misspell_go_path ]]; then
       misspell_go_command="$misspell_go_path $path"
@@ -162,7 +150,7 @@ function bench_file() {
     if [[ ! -z $codespell_path ]]; then
       codespell_command="$codespell_path $path"
     fi
-    hyperfine --warmup 1 -i --export-json $report_prefix-rg.json --export-markdown $report_prefix-rg.md "$rg_command" "$typos_command" "$typos_ascii_command" "$misspell_rs_command" "$misspell_go_command" "$scspell_command" "$codespell_command"
+    hyperfine --warmup 1 -i --export-json $report_prefix-rg.json --export-markdown $report_prefix-rg.md "$rg_command" "$typos_command" "$typos_ascii_command" "$misspell_go_command" "$scspell_command" "$codespell_command"
     cat $report_prefix-rg.md >> $output
   fi
   echo "" >> $output
@@ -184,17 +172,17 @@ ripgrep_built_path=`$current_dir/fixtures/ripgrep_built.sh path $base_dir`
 ripgrep_built_version=`$current_dir/fixtures/ripgrep_built.sh version $base_dir`
 bench_dir "ripgrep_built" "$ripgrep_built_version" "$ripgrep_built_path" "$report_path"
 
-# subtitles_en_path=`$current_dir/fixtures/subtitles_en.sh path $base_dir`
-# subtitles_en_version=`$current_dir/fixtures/subtitles_en.sh version $base_dir`
-# bench_file "subtitles_en" "$subtitles_en_version" "$subtitles_en_path" "$report_path"
+subtitles_en_path=`$current_dir/fixtures/subtitles_en.sh path $base_dir`
+subtitles_en_version=`$current_dir/fixtures/subtitles_en.sh version $base_dir`
+bench_file "subtitles_en" "$subtitles_en_version" "$subtitles_en_path" "$report_path"
 
-# subtitles_en_small_path=`$current_dir/fixtures/subtitles_en_small.sh path $base_dir`
-# subtitles_en_small_version=`$current_dir/fixtures/subtitles_en_small.sh version $base_dir`
-# bench_file "subtitles_en_small" "$subtitles_en_small_version" "$subtitles_en_small_path" "$report_path"
+subtitles_en_small_path=`$current_dir/fixtures/subtitles_en_small.sh path $base_dir`
+subtitles_en_small_version=`$current_dir/fixtures/subtitles_en_small.sh version $base_dir`
+bench_file "subtitles_en_small" "$subtitles_en_small_version" "$subtitles_en_small_path" "$report_path"
 
-# subtitles_ru_path=`$current_dir/fixtures/subtitles_ru.sh path $base_dir`
-# subtitles_ru_version=`$current_dir/fixtures/subtitles_ru.sh version $base_dir`
-# bench_file "subtitles_ru" "$subtitles_ru_version" "$subtitles_ru_path" "$report_path"
+subtitles_ru_path=`$current_dir/fixtures/subtitles_ru.sh path $base_dir`
+subtitles_ru_version=`$current_dir/fixtures/subtitles_ru.sh version $base_dir`
+bench_file "subtitles_ru" "$subtitles_ru_version" "$subtitles_ru_path" "$report_path"
 
 subtitles_ru_small_path=`$current_dir/fixtures/subtitles_ru_small.sh path $base_dir`
 subtitles_ru_small_version=`$current_dir/fixtures/subtitles_ru_small.sh version $base_dir`
