@@ -126,7 +126,7 @@ pub(crate) struct FileArgs {
     check_filenames: bool,
 
     #[structopt(long, overrides_with("check-files"))]
-    /// Skip verifying spelling in filess.
+    /// Skip verifying spelling in files.
     no_check_files: bool,
     #[structopt(long, overrides_with("no-check-files"), hidden(true))]
     check_files: bool,
@@ -200,8 +200,8 @@ impl ConfigArgs {
 #[derive(Debug, StructOpt)]
 #[structopt(rename_all = "kebab-case")]
 pub(crate) struct WalkArgs {
-    #[structopt(long)]
-    /// Ignore all files & directories matching the pattern.
+    #[structopt(long, name = "GLOB")]
+    /// Ignore files & directories matching the glob.
     exclude: Vec<String>,
 
     #[structopt(long, overrides_with("no-hidden"))]
